font_scaler library

Classes

FontScaler
//////// ******* FontScaler Class ******** ////////// This is the Main Class of where all logic is written.
FontScalerProvider
This Package is develop by MIRZA AZMATHULLAH BAIG. This is the FontScalerProvider class extends with InheritedWidget which will store the data and can be access from any where.
MirzaAppString
//// ****** String Class ****** //////////

Enums

FontScale
//// ****** enum ****** ////////// here one enum has created for fontScaling the with predefined values below in map and also have the custom for customization of the font Scale from userEnd

Properties

fontScaleMap Map<FontScale, double>
//// ****** Value Map ****** ////////// fontScaleMap will store the value of the Font Scale
getter/setter pair

Functions

getFontScaleFromValue(double value) FontScale
//// ****** getFontScaleFromValue ****** ////////// this will return the key based on the value if the value not exist then it return custom