This Package is develop by MIRZA AZMATHULLAH BAIG.
This is the FontScalerProvider class extends with InheritedWidget which will
store the data and can be access from any where.
//// ****** enum ****** //////////
here one enum has created for fontScaling the with predefined values below in map
and also have the custom for customization of the font Scale from userEnd